@@ -1,7 +1,7 @@
-/* $Id: minissdp.h,v 1.13 2014/04/20 16:34:27 nanard Exp $ */
+/* $Id: minissdp.h,v 1.14 2017/05/24 22:26:35 nanard Exp $ */
 /* MiniUPnP project
  * http://miniupnp.free.fr/ or http://miniupnp.tuxfamily.org/
- * (c) 2006-2014 Thomas Bernard
+ * (c) 2006-2017 Thomas Bernard
  * This software is subject to the conditions detailed
  * in the LICENCE file provided within the distribution */
 #ifndef MINISSDP_H_INCLUDED
@@ -39,12 +39,12 @@ ProcessSSDPRequest(int s, unsigned short http_port);
 #ifdef ENABLE_HTTPS
 void
 ProcessSSDPData(int s, const char *bufr, int n,
-                const struct sockaddr * sendername,
+                const struct sockaddr * sendername, int source_if,
                 unsigned short http_port, unsigned short https_port);
 #else
 void
 ProcessSSDPData(int s, const char *bufr, int n,
-                const struct sockaddr * sendername,
+                const struct sockaddr * sendername, int source_if,
                 unsigned short http_port);
 #endif
 
