@@ -1,9 +1,9 @@
-/* $Id: options.c,v 1.43 2022/10/21 19:45:26 nanard Exp $ */
+/* $Id: options.c,v 1.44 2023/05/27 09:27:20 nanard Exp $ */
 /* vim: tabstop=4 shiftwidth=4 noexpandtab
  * MiniUPnP project
  * http://miniupnp.free.fr/ or https://miniupnp.tuxfamily.org/
  * author: Ryan Wagoner
- * (c) 2006-2022 Thomas Bernard
+ * (c) 2006-2023 Thomas Bernard
  * This software is subject to the conditions detailed
  * in the LICENCE file provided within the distribution */
 
@@ -75,7 +75,9 @@ static const struct {
 	{ UPNPNATPOSTCHAIN, "upnp_nat_postrouting_chain"},
 #endif
 #ifdef ENABLE_NATPMP
+	/* both NAT-PMP and PCP (when PCP is enabled at compile time) */
 	{ UPNPENABLENATPMP, "enable_natpmp"},
+	{ UPNPENABLENATPMP, "enable_pcp_pmp"},
 #endif
 #ifdef ENABLE_PCP
 	{ UPNPPCPMINLIFETIME, "min_lifetime"},
