@@ -1,8 +1,8 @@
-/* $Id: upnpredirect.c,v 1.98 2020/12/03 23:29:53 nanard Exp $ */
+/* $Id: upnpredirect.c,v 1.99 2022/10/21 19:44:59 nanard Exp $ */
 /* vim: tabstop=4 shiftwidth=4 noexpandtab
  * MiniUPnP project
  * http://miniupnp.free.fr/ or https://miniupnp.tuxfamily.org/
- * (c) 2006-2020 Thomas Bernard
+ * (c) 2006-2022 Thomas Bernard
  * This software is subject to the conditions detailed
  * in the LICENCE file provided within the distribution */
 
@@ -351,9 +351,9 @@ upnp_redirect(const char * rhost, unsigned short eport,
 	}
 
 	if(!check_upnp_rule_against_permissions(upnppermlist, num_upnpperm,
-	                                        eport, address, iport)) {
+	                                        eport, address, iport, desc)) {
 		syslog(LOG_INFO, "redirection permission check failed for "
-		                 "%hu->%s:%hu %s", eport, iaddr, iport, protocol);
+		                 "%hu->%s:%hu %s %s", eport, iaddr, iport, protocol, desc);
 		return -3;
 	}
 
