@@ -1,4 +1,4 @@
-/* $Id: upnpsoap.c,v 1.164 2023/02/11 23:03:09 nanard Exp $ */
+/* $Id: upnpsoap.c,v 1.166 2024/01/04 01:03:14 nanard Exp $ */
 /* vim: tabstop=4 shiftwidth=4 noexpandtab
  * MiniUPnP project
  * http://miniupnp.free.fr/ or https://miniupnp.tuxfamily.org/
@@ -2101,7 +2101,7 @@ CheckPinholeWorking(struct upnphttp * h, const char * action, const char * ns)
 			return ;
 		if(packets == 0)
 		{
-			SoapError(h, 709, "NoPacketSent");
+			SoapError(h, 709, "NoTrafficReceived");
 			return;
 		}
 		bodylen = snprintf(body, sizeof(body), resp,
@@ -2344,23 +2344,21 @@ void
 ExecuteSoapAction(struct upnphttp * h, const char * action, int n)
 {
 	char * p;
-	char * p2;
 	int i, len, methodlen;
 	char namespace[256];
 
 	/* SoapAction example :
 	 * urn:schemas-upnp-org:service:WANIPConnection:1#GetStatusInfo */
-	p = strchr(action, '#');
-	if(p && (p - action) < n) {
+	p = memchr(action, '#', n);
+	if(p) {
 		for(i = 0; i < ((int)sizeof(namespace) - 1) && (action + i) < p; i++)
 			namespace[i] = action[i];
 		namespace[i] = '\0';
 		p++;
-		p2 = strchr(p, '"');
-		if(p2 && (p2 - action) <= n)
-			methodlen = p2 - p;
-		else
-			methodlen = n - (p - action);
+		methodlen = n - (int)(p - action);
+		if(p[methodlen-1] == '"') {
+			methodlen--;	/* remove the ending " */
+		}
 		/*syslog(LOG_DEBUG, "SoapMethod: %.*s %d %d %p %p %d",
 		       methodlen, p, methodlen, n, action, p, (int)(p - action));*/
 		for(i = 0; soapMethods[i].methodName; i++) {
